==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/GetIotConnectorFhirDestinationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fhirDestinationName The name of IoT Connector FHIR destination resource.
 * @property iotConnectorName The name of IoT Connector resource.
 * @property resourceGroupName The name of the resource group that contains the service instance.
 * @property workspaceName The name of workspace resource.
 */
public data class GetIotConnectorFhirDestinationPlainArgs(
    public val fhirDestinationName: String,
    public val iotConnectorName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs =
        com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs.builder()
            .fhirDestinationName(fhirDestinationName.let({ args0 -> args0 }))
            .iotConnectorName(iotConnectorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIotConnectorFhirDestinationPlainArgs].
 */
@PulumiTagMarker
public class GetIotConnectorFhirDestinationPlainArgsBuilder internal constructor() {
    private var fhirDestinationName: String? = null

    private var iotConnectorName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of IoT Connector FHIR destination resource.
     */
    @JvmName("ursxbjedxbijvqrg")
    public suspend fun fhirDestinationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.fhirDestinationName = mapped
    }

    /**
     * @param value The name of IoT Connector resource.
     */
    @JvmName("jvrcknjgxdqssdpd")
    public suspend fun iotConnectorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.iotConnectorName = mapped
    }

    /**
     * @param value The name of the resource group that contains the service instance.
     */
    @JvmName("ojvdyjlaagapncwp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of workspace resource.
     */
    @JvmName("uqxvlvphbybpjovy")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetIotConnectorFhirDestinationPlainArgs =
        GetIotConnectorFhirDestinationPlainArgs(
            fhirDestinationName = fhirDestinationName ?: throw PulumiNullFieldException("fhirDestinationName"),
            iotConnectorName = iotConnectorName ?: throw PulumiNullFieldException("iotConnectorName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/GetIotConnectorFhirDestinationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fhirDestinationName The name of IoT Connector FHIR destination resource.
 * @property iotConnectorName The name of IoT Connector resource.
 * @property resourceGroupName The name of the resource group that contains the service instance.
 * @property workspaceName The name of workspace resource.
 */
public data class GetIotConnectorFhirDestinationPlainArgs(
    public val fhirDestinationName: String,
    public val iotConnectorName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs =
        com.pulumi.azurenative.healthcareapis.inputs.GetIotConnectorFhirDestinationPlainArgs.builder()
            .fhirDestinationName(fhirDestinationName.let({ args0 -> args0 }))
            .iotConnectorName(iotConnectorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIotConnectorFhirDestinationPlainArgs].
 */
@PulumiTagMarker
public class GetIotConnectorFhirDestinationPlainArgsBuilder internal constructor() {
    private var fhirDestinationName: String? = null

    private var iotConnectorName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of IoT Connector FHIR destination resource.
     */
    @JvmName("eduvlafxkbpvbotr")
    public suspend fun fhirDestinationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.fhirDestinationName = mapped
    }

    /**
     * @param value The name of IoT Connector resource.
     */
    @JvmName("vypsxojaytwyligh")
    public suspend fun iotConnectorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.iotConnectorName = mapped
    }

    /**
     * @param value The name of the resource group that contains the service instance.
     */
    @JvmName("lkpnkmhebpkhxsci")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of workspace resource.
     */
    @JvmName("irtvuqeechvmpegd")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetIotConnectorFhirDestinationPlainArgs =
        GetIotConnectorFhirDestinationPlainArgs(
            fhirDestinationName = fhirDestinationName ?: throw PulumiNullFieldException("fhirDestinationName"),
            iotConnectorName = iotConnectorName ?: throw PulumiNullFieldException("iotConnectorName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}
